==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-desktopswitch/translations/desktopswitch_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="85"/>
        <source>Switch to desktop %1</source>
        <translation>Trocar para o ambiente de trabalho %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="144"/>
        <location filename="../desktopswitch.cpp" line="155"/>
        <source>Desktop %1</source>
        <translation>Ambiente de trabalho %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation>Definições do alternador</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Número de linhas:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Texto do ambiente de trabalho:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Números</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Nomes</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>Se ativada, o widget será apenas um indicador</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>Mostrar apenas a área de trabalho ativa</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>Nome dos ambiente de trabalho</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="69"/>
        <source>Desktop %1:</source>
        <translation>Ambiente de trabalho %1:</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-desktopswitch/translations/desktopswitch_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="95"/>
        <source>Switch to desktop %1</source>
        <translation>Trocar para a área de trabalho %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="170"/>
        <location filename="../desktopswitch.cpp" line="181"/>
        <source>Desktop %1</source>
        <translation>Área de trabalho %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch Settings</source>
        <translation>Definições do DesktopSwitch</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Número de linhas:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Texto da área de trabalho:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Números</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Nomes</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>Se ativada, o widget será apenas um indicador</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>Mostrar apenas a área de trabalho ativa</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>Nomes da áreas de trabalho</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="78"/>
        <source>Desktop %1:</source>
        <translation>Área de trabalho %1:</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchUnsupported</name>
    <message>
        <location filename="../desktopswitch.cpp" line="342"/>
        <source>n/a</source>
        <translation>n/d</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="344"/>
        <source>DesktopSwitch is unsupported on current platform: %1</source>
        <translation>O DesktopSwitch não é suportado na plataforma atual: %1</translation>
    </message>
</context>
</TS>
